.. include:: /_includes/wip_prolog.rst

:mod:`stix.coa` Module
==================================

.. module:: stix.coa

Classes
-------

.. autoclass:: CourseOfAction
	:show-inheritance:
	:members:

.. autoclass:: RelatedCOAs
	:show-inheritance:
	:members:
